## dbt-bigquery 1.11.0-rc2 - December 09, 2025

### Features

- :bug: :snowman: Support batched source freshness in bigquery using TABLE_STORAGE, behind behavior change flag. ([#561](https://github.com/dbt-labs/dbt-adapters/issues/561))
- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))
